@@ -1,7 +1,7 @@
 /* rep_node:  Eliminates duplicate files based on filenode.  Utilizes the output
    of the filenode command.
 
-   Copyright (C) 2005-2007 by Brian Lindholm.
+   Copyright (C) 2005-2020 by Brian Lindholm.
    This file is part of the littleutils utility set.
 
    The rep_node utility is free software; you can redistribute it and/or modify
@@ -18,12 +18,18 @@
    the littleutils.  If not, see <https://www.gnu.org/licenses/>. */
 
 
+#include <config.h>
+
 #include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
+# include <string.h>
+#endif
 
 #ifndef LINE_MAX
-#define LINE_MAX 8192
+# define LINE_MAX 8192
 #endif
 
 
